"""
default exception
"""
je_editor_error = "JEditor error"
"""
exec exception
"""
je_editor_exec_error = "JEditor exec error"
file_not_fond_error = "File not fond"
je_editor_compiler_not_found_error = "Compiler not found"
"""
shell exception
"""
je_editor_shell_error = "JEditor run on shell error"
"""
file exception
"""
je_editor_save_file_error = "JEditor save file error"
je_editor_open_file_error = "JEditor open file error"
"""
json exception
"""
je_editor_cant_reformat_json_error = "Can't reformat json is type right?"
je_editor_wrong_json_data_error = "Can't parser json"
"""
content data error
"""
# TODO THIS EXCEPTION
je_editor_content_set_compiler_error = "When set compiler using content make an error"
je_editor_content_file_error = "JEditor content file error"

